@@ -25,15 +25,8 @@
 int main()
 {
   using namespace __gnu_test;
-
- // cplus-dem FAIL
-  // Equivalent as considered order-insensitive?
-  // standard text, icc FAIL
-  //  verify_demangle("_ZlsRKU3fooU4bart1XS0_", 
-  //     "operator<<(X const foo bart&, X const foo bart)");
-  // new __cxa_demangle
-  verify_demangle("_ZlsRKU3fooU4bart1XS0_", 
-		  "operator<<(X bart foo const&, X bart)");
+  // cplus-dem FAIL
+  verify_demangle("_Z1fA37_iPS_", "f(int [37], int (*) [37])");
 
   return 0;
 }
